@@ -10,11 +10,12 @@ log = logging.getLogger(sys.modules[__name__].__name__)
 
 
 class LazyLoadingCachePolicy(CachePolicy):
-    def __init__(self, config_fetcher, config_cache, cache_time_to_live_seconds=60):
+    def __init__(self, config_fetcher, config_cache, cache_key, cache_time_to_live_seconds=60):
         if cache_time_to_live_seconds < 1:
             cache_time_to_live_seconds = 1
         self._config_fetcher = config_fetcher
         self._config_cache = config_cache
+        self._cache_key = cache_key
         self._cache_time_to_live = datetime.timedelta(seconds=cache_time_to_live_seconds)
         self._lock = ReadWriteLock()
         self._last_updated = None
@@ -25,7 +26,7 @@ class LazyLoadingCachePolicy(CachePolicy):
         try:
             self._lock.acquire_read()
 
-            config = self._config_cache.get()
+            config = self._config_cache.get(self._cache_key)
 
             utc_now = datetime.datetime.utcnow()
             if self._last_updated is not None and self._last_updated + self._cache_time_to_live > utc_now:
@@ -47,7 +48,7 @@ class LazyLoadingCachePolicy(CachePolicy):
 
         try:
             self._lock.acquire_read()
-            config = self._config_cache.get()
+            config = self._config_cache.get(self._cache_key)
             return config
         finally:
             self._lock.release_read()
@@ -57,7 +58,7 @@ class LazyLoadingCachePolicy(CachePolicy):
 
         try:
             self._lock.acquire_read()
-            config = self._config_cache.get()
+            config = self._config_cache.get(self._cache_key)
             force_fetch = not bool(config)
         finally:
             self._lock.release_read()
@@ -78,7 +79,7 @@ class LazyLoadingCachePolicy(CachePolicy):
             self._last_updated = datetime.datetime.utcnow()
             if configuration_response.is_fetched():
                 configuration = configuration_response.json()
-                self._config_cache.set(configuration)
+                self._config_cache.set(self._cache_key, configuration)
         except HTTPError as e:
             log.error('Double-check your SDK Key at https://app.configcat.com/sdkkey.'
                       ' Received unexpected response: %s' % str(e.response))
